==> hiver-common-1.0.0-sources.jar: plus/hiver/common/constant/HiverConstant.java <==
/*
 * Copyright 2023-2025 Licensed under the AGPL License
 */
package plus.hiver.common.constant;

/**
 * 全局常量
 *
 * <p>
 * 尊重知识产权，CV 请保留版权，海文科技 https://hiver.cc 出品，不允许非法使用，后果自负
 * </p>
 *
 * @author Yazhi Li
 */
public interface HiverConstant {
    /**
     * 日期格式化 年月日时分秒
     */
    String DATE_MM_SS = "yyyy-MM-dd HH:mm:ss";

    /**
     * 日期格式化 年月日时分
     */
    String DATE_MM = "yyyy-MM-dd HH:mm";

    /**
     * 日期格式化 时区
     */
    String GMT8 = "GMT+8";

    /**
     * 限流前缀
     */
    String LIMIT_PRE = "HIVER_LIMIT:";

    /**
     * 限流标识
     */
    String LIMIT_ALL = "HIVER_LIMIT_ALL";

    /**
     * 顶部菜单类型权限
     */
    Integer PERMISSION_NAV = -1;

    /**
     * 页面类型权限
     */
    Integer PERMISSION_PAGE = 0;

    /**
     * 操作类型权限
     */
    Integer PERMISSION_OPERATION = 1;

    /**
     * 全部数据权限
     */
    Integer DATA_TYPE_ALL = 0;

    /**
     * 自定义数据权限
     */
    Integer DATA_TYPE_CUSTOM = 1;

    /**
     * 本部门及以下
     */
    Integer DATA_TYPE_UNDER = 2;

    /**
     * 本部门
     */
    Integer DATA_TYPE_SAME = 3;

    /**
     * 自己
     */
    Integer DATA_TYPE_SELF = 4;

    /**
     * 正常状态
     */
    Integer STATUS_NORMAL = 0;

    /**
     * 部门负责人类型 主负责人
     */
    Integer HEADER_TYPE_MAIN = 0;

    /**
     * 部门负责人类型 副负责人
     */
    Integer HEADER_TYPE_VICE = 1;

    /**
     * 1级菜单父id
     */
    String PARENT_ID = "0";

    /**
     * 0级菜单
     */
    Integer LEVEL_ZERO = 0;

    /**
     * 1级菜单
     */
    Integer LEVEL_ONE = 1;

    /**
     * 2级菜单
     */
    Integer LEVEL_TWO = 2;

    /**
     * 3级菜单
     */
    Integer LEVEL_THREE = 3;
}

==> hiver-common-1.0.5.4-sources.jar: plus/hiver/common/constant/HiverConstant.java <==
/*
 * Copyright 2023-2025 Licensed under the AGPL License
 */
package plus.hiver.common.constant;

/**
 * 全局常量
 *
 * <p>
 * 尊重知识产权，CV 请保留版权，海文科技 https://hiver.cc 出品，不允许非法使用，后果自负
 * </p>
 *
 * @author Yazhi Li
 */
public interface HiverConstant {
    /**
     * 日期格式化 年月日时分秒
     */
    String DATE_MM_SS = "yyyy-MM-dd HH:mm:ss";

    /**
     * 日期格式化 年月日时分
     */
    String DATE_MM = "yyyy-MM-dd HH:mm";

    /**
     * 日期格式化 时区
     */
    String GMT8 = "GMT+8";

    /**
     * 限流前缀
     */
    String LIMIT_PRE = "HIVER_LIMIT:";

    /**
     * 限流标识
     */
    String LIMIT_ALL = "HIVER_LIMIT_ALL";

    /**
     * 顶部菜单类型权限
     */
    Integer PERMISSION_NAV = -1;

    /**
     * 页面类型权限
     */
    Integer PERMISSION_PAGE = 0;

    /**
     * 操作类型权限
     */
    Integer PERMISSION_OPERATION = 1;

    /**
     * 全部数据权限
     */
    Integer DATA_TYPE_ALL = 0;

    /**
     * 自定义数据权限
     */
    Integer DATA_TYPE_CUSTOM = 1;

    /**
     * 本部门及以下
     */
    Integer DATA_TYPE_UNDER = 2;

    /**
     * 本部门
     */
    Integer DATA_TYPE_SAME = 3;

    /**
     * 自己
     */
    Integer DATA_TYPE_SELF = 4;

    /**
     * 正常状态
     */
    Integer STATUS_NORMAL = 0;

    /**
     * 禁用状态
     */
    Integer STATUS_DISABLE = -1;

    /**
     * 部门负责人类型 主负责人
     */
    Integer HEADER_TYPE_MAIN = 0;

    /**
     * 部门负责人类型 副负责人
     */
    Integer HEADER_TYPE_VICE = 1;

    /**
     * 1级菜单父id
     */
    String PARENT_ID = "0";

    /**
     * 0级菜单
     */
    Integer LEVEL_ZERO = 0;

    /**
     * 1级菜单
     */
    Integer LEVEL_ONE = 1;

    /**
     * 2级菜单
     */
    Integer LEVEL_TWO = 2;

    /**
     * 3级菜单
     */
    Integer LEVEL_THREE = 3;

    /**
     * 短信验证码key前缀
     */
    String PRE_SMS = "HIVER_PRE_SMS:";

    /**
     * 邮件验证码key前缀
     */
    String PRE_EMAIL = "HIVER_PRE_EMAIL:";

    /**
     * SM2名称
     */
    String BOUNCY_NAME = "sm2p256v1";

    /**
     * 逻辑删除标志 false
     */
    Integer DEL_FLAG_FALSE = 0;

    /**
     * 逻辑删除标志 true
     */
    Integer DEL_FLAG_TRUE = 1;

    /**
     * 删除至回收站标志
     */
    Integer DEL_FLAG_TRASH = 2;
}
